@@ -1,7 +1,7 @@
-from TraceUts import traceMap
-import TraceUts
+from traceUts import traceMap
+import traceUts
 
-TraceUts.CallBack = lambda x:print(x)
+traceUts.CallBack = lambda x:print(x)
 
 @traceMap(main=True)
 def soma(a,b):
